@@ -4,7 +4,7 @@ use base qw/Prty::Object/;
 use strict;
 use warnings;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
 use Prty::Object;
 use Prty::Perl;
@@ -170,6 +170,24 @@ sub index {
 
 # -----------------------------------------------------------------------------
 
+=head3 last() - Liefere letztes Element
+
+=head4 Synopsis
+
+    $e = $arr->last;
+    $e = $class->last(\@arr);
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub last {
+    my $arr = ref $_[0]? CORE::shift: CORE::splice @_,0,2;
+    return $arr->[-1];
+}
+
+# -----------------------------------------------------------------------------
+
 =head3 maxLength() - Länge des längsten Elements
 
 =head4 Synopsis
@@ -598,7 +616,7 @@ sub median {
 
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
