@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
 use Scalar::Util ();
 use Hash::Util ();
@@ -668,7 +668,7 @@ sub hashSize {
 
 Prüfe die Schlüssel des Hash %hash gegen die Schlüssel in Array
 @keys bzw. Hash %keys. Enthält %hash einen Schlüssel, der nicht in
-@keys bzw. %keys vorkommt, wirf eine Exception.
+@keys bzw. %keys vorkommt, wird eine Exception geworfen.
 
 =cut
 
@@ -743,13 +743,32 @@ sub copy {
 
 =head4 Synopsis
 
-    $h->join(\%hash);
+    $h = $h->join(\%hash);
+
+=head4 Returns
+
+Hash (für Method Chaining)
 
 =head4 Description
 
 Überschreibe die Schlüssel/Wert-Paare in Hash $h mit den
 Schlüssel/Wert-Paaren aus Hash %hash. Schlüssel/Wert-Paare
 in Hash $h, die in Hash %hash nicht vorkommen, bleiben bestehen.
+Enthält %hash einen Schlüssel, der in $h nicht vorkommt, wird eine
+Exception geworfen.
+
+=head4 Example
+
+Ein Hash-Objekt mit vorgegebenen Attributen aus einem anoymen Hash
+erzeugen. Der anonyme Hash darf weniger, aber nicht mehr Attribute
+enthalten:
+
+    $h = Prty::Hash->new([qw/
+        name
+        label
+        width
+        height
+    /])->join(\%hash);
 
 =cut
 
@@ -762,7 +781,7 @@ sub join {
         $self->{$key} = $hash->{$key};
     }
     
-    return;
+    return $self;
 }
 
 # -----------------------------------------------------------------------------
@@ -1356,7 +1375,7 @@ Das Benchmark-Programm (bench-hash):
 
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
