@@ -4,7 +4,7 @@ use base qw/Prty::Html::Table::Base/;
 use strict;
 use warnings;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
 use Prty::Html::Tag;
 
@@ -20,7 +20,65 @@ Prty::Html::Table::List - HTML-Tabelle zum Anzeigen einer Liste von Elementen
 
 L<Prty::Html::Table::Base>
 
-=head1 SYNOPSIS
+=head1 DESCRIPTION
+
+Die Klasse erzeugt eine HTML-Tabelle aus einer Liste von
+Objekten. Jedes Objekt wird durch eine Zeile dargestellt. Alle
+Zeilen- (tr-Elemente) und Zellenattribute (td-Elemente) können
+gesetzt werden. Die Klasse ist daher sehr flexibel.
+
+Für jedes Objekt wird die Methode $e->rowCallback() gerufen.
+Die Methode bekommt das Objekt und seine (0-basierte) Position in der
+Liste der Objekte (Attribut "rows") übergeben. Die Methode liefert
+die Spezifikation für die Zeile (tr) und ihre Zellen (td) zurück,
+wobei jede Spezifikation ein Array ist, das unmittelbar an
+die Methode tag() übergeben wird.
+
+=head1 ATTRIBUTES
+
+Zusätzlich zu den Attributen der Basisklasse definiert die Klasse
+folgende Attribute:
+
+=over 4
+
+=item align => \@arr (Default: [])
+
+Ausrichtung des Kolumneninhalts.
+
+=item allowHtml => $bool|\@titles (Default: 0)
+
+Erlaube HTML insgesamt oder auf den Kolumnen in @titles,
+d.h. ersetze die Werte der Kolumnen &, <, > I<nicht> automatisch
+durch HTML-Entities.
+
+=item empty => $str (Default: '&nbsp;')
+
+HTML-Code, der im Body der Tabelle gesetzt wird, wenn die Liste
+der Elemente leer ist. Wenn auf Leerstring, undef oder 0 gesetzt,
+wird kein Body angezeigt.
+
+=item rowCallback => $sub (Default: undef)
+
+Referenz auf eine Subroutine, die für jedes Element die
+darzustellende Zeileninformation (für tr- und td-Tag) liefert.
+
+=item rowCallbackArguments => \@args (Default: [])
+
+Liste von Argumenten, die I<zusätzlich> zu den Standardargumenten
+an die Subroutine rowCallback() übergeben werden.
+
+=item rows => \@rows (Default: [])
+
+Liste der Elemente. Für jedes Element wird die Callback-Methode
+(Attribut rowCallback) aufgerufen.
+
+=item titles => \@titles (Default: [])
+
+Liste der Kolumnentitel.
+
+=back
+
+=head1 EXAMPLES
 
 Attribute von tr- und td-Elemeten setzen. Für jedes Element
 wird eine Arrayreferenz geliefert:
@@ -59,68 +117,17 @@ für die td-Elemente ein skalarer Wert (der Content des Elements):
     );
     $html = $e->html($h);
 
-=head1 DESCRIPTION
-
-Die Klasse erzeugt eine Tabelle aus einer Liste von Objekten. Jedes
-Objekt wird durch eine Zeile dargestellt. Alle Zeilen- (tr) und
-Zellenattribute (td) können kontrolliert werden. Die Klasse ist
-daher sehr flexibel.
-
-Für jedes Objekt wird die Methode $e->rowCallback() gerufen.
-Die Methode bekommt das Objekt und seine (0-basierte) Position in der
-Liste der Objekte (Attribut "rows") übergeben. Die Methode liefert
-die Spezifikation für die Zeile (tr) und ihre Zellen (td) zurück,
-wobei jede Spezifikation ein Array ist, das unmittelbar an
-die Methode tag() übergeben wird.
-
-=head1 ATTRIBUTES
-
-Zusätzlich zu den Attributen der Basisklasse definiert die Klasse
-folgende Attribute:
-
-=over 4
-
-=item align => \@arr (Default: [])
-
-Ausrichtung des Kolumneninhalts.
-
-=item allowHtml => $bool|\@titles (Default: 0)
-
-Erlaube HTML insgesamt oder auf den Kolumnen in @titles,
-d.h. ersetze die Werte der Kolumnen &, <, > I<nicht> automatisch
-durch HTML-Entities.
-
-=item empty => $str (Default: '&nbsp;')
-
-HTML-Code, der im Body der Tabelle gesetzt wird, wenn die Liste
-der Elemente leer ist. Wenn auf Leerstring, undef oder 0 gesetzt,
-wird kein Body angezeigt.
-
-=item rowCallback => $ref (Default: undef)
-
-Referenz auf eine Subroutine, die für jedes Element die
-darzustellende Zeileninformation (für tr- und td-Tag) liefert.
-
-=item rows => \@rows (Default: [])
-
-Liste der Elemente. Für jedes Element wird die Callback-Methode
-(Attribut rowCallback) aufgerufen.
-
-=item titles => \@titles (Default: [])
-
-Liste der Kolumnentitel.
-
-=back
-
 =head1 METHODS
 
-=head2 new() - Konstruktor
+=head2 Konstruktor
 
-=head3 Synopsis
+=head3 new() - Instantiiere Objekt
+
+=head4 Synopsis
 
     $e = $class->new(@attVal);
 
-=head3 Description
+=head4 Description
 
 Instantiiere ein Tabellenobjekt mit den Eingenschaften @attVal und
 liefere eine Referenz auf dieses Objekt zurück.
@@ -140,6 +147,7 @@ sub new {
         allowHtml=>0,
         empty=>'&nbsp;',
         rowCallback=>undef,
+        rowCallbackArguments=>[],
         rows=>[],
         titles=>[],
     );
@@ -152,14 +160,16 @@ sub new {
 
 # -----------------------------------------------------------------------------
 
-=head2 html() - Generiere HTML-Code
+=head2 Objektmethoden
 
-=head3 Synopsis
+=head3 html() - Generiere HTML
+
+=head4 Synopsis
 
     $html = $e->html($h);
     $html = $class->html($h,@attVal);
 
-=head3 Description
+=head4 Description
 
 Generiere HTML-Code für Tabellenobjekt $e und liefere diesen zurück.
 Bei Aufruf als Klassenmethode wird das Tabellenobjekt von
@@ -178,26 +188,27 @@ sub html {
 
     # Attribute
 
-    my ($align,$allowHtml,$empty,$rowCallback,$rows,$titles) =
-        $self->get(qw/align allowHtml empty rowCallback rows titles/);
+    my ($align,$allowHtml,$empty,$rowCallback,$rowCallbackArgumentA,$rowA,
+        $titleA) = $self->get(qw/align allowHtml empty rowCallback
+        rowCallbackArguments rows titles/);
 
-    return '' if !@$titles && !@$rows;
+    return '' if !@$titleA && !@$rowA;
 
-    if (@$rows && !$rowCallback) {
+    if (@$rowA && !$rowCallback) {
         $self->throw(
             q{HTML-00001: Keine Callback-Methode (rowCallback) definiert}
         );
     }
 
     my %allowHtml;
-    @allowHtml{@$titles} = (0) x @$titles;
+    @allowHtml{@$titleA} = (0) x @$titleA;
     if (ref $allowHtml) {
         # $allowHtml als Referenz auf Array von bestimmten Kolumnen
         @allowHtml{@$allowHtml} = (1) x @$allowHtml;
     }
     elsif ($allowHtml) {
         # $allowHtml als boolscher Wert für alle Kolumnen
-        @allowHtml{@$titles} = (1) x @$titles;
+        @allowHtml{@$titleA} = (1) x @$titleA;
     }
 
     # Tabelleninhalt
@@ -206,10 +217,10 @@ sub html {
 
     # Kopf
 
-    if (@$titles) {
+    if (@$titleA) {
         my $ths;
         my $i = 0;
-        for my $title (@$titles) {
+        for my $title (@$titleA) {
             $ths .= $h->tag('th',
                 -text=>!$allowHtml{$title},
                 align=>$align->[$i++],
@@ -226,14 +237,13 @@ sub html {
 
     my $trs;
     my $i = 0;
-    for my $row (@$rows) {
-        my ($trA,@tds) = $rowCallback->($row,$i++);        
-
+    for my $row (@$rowA) {
+        my ($trA,@tds) = $rowCallback->($row,$i++,@$rowCallbackArgumentA);
         my $tds;
         my $j = 0;
         for my $tdA (@tds) {
             $tds .= $h->tag('td',
-                -text=>!$allowHtml{$titles->[$j]},
+                -text=>!$allowHtml{$titleA->[$j]},
                 align=>$align->[$j++],
                 ref $tdA? @$tdA: $tdA # Array oder skalarer Wert
             );
@@ -249,7 +259,7 @@ sub html {
         $trs = $h->tag('tr',
             $h->tag('td',
                 align=>'center',
-                colspan=>scalar(@$titles),
+                colspan=>scalar(@$titleA),
                 '-',
                 $empty,
             )
@@ -266,7 +276,7 @@ sub html {
 
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
