@@ -4,7 +4,7 @@ use base qw/Prty::Html::Widget/;
 use strict;
 use warnings;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
 use Prty::Html::Tag;
 
@@ -61,6 +61,10 @@ JavaScript-Handler.
 
 Breite des Feldes in Zeichen.
 
+=item title => $text (Deafult: undef)
+
+Text Tooltip.
+
 =item value => $str (Default: undef)
 
 Anfänglicher Wert des Textfelds.
@@ -95,6 +99,7 @@ sub new {
         onKeyUp=>undef,
         size=>undef,
         style=>undef,
+        title=>undef,
         value=>undef,
     );
 
@@ -126,9 +131,9 @@ sub html {
 
     # Attribute
 
-    my ($class,$disabled,$id,$maxLength,$name,$onKeyUp,$size,$style,$value) =
-        $self->get(qw/class disabled id maxLength name onKeyUp size style
-        value/);
+    my ($class,$disabled,$id,$maxLength,$name,$onKeyUp,$size,$style,
+        $title,$value) = $self->get(qw/class disabled id maxLength name
+        onKeyUp size style title value/);
 
     if (!defined $maxLength) {
         $maxLength = $size;
@@ -150,6 +155,7 @@ sub html {
         size=>$size,
         maxlength=>$maxLength,
         value=>$value,
+        title=>$title,
     );    
 }
 
@@ -157,7 +163,7 @@ sub html {
 
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
