@@ -4,10 +4,10 @@ use base qw/Prty::Hash/;
 use strict;
 use warnings;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
-use Prty::Hash;
 use Prty::Html::Table::List;
+use Prty::Hash;
 
 # -----------------------------------------------------------------------------
 
@@ -35,7 +35,9 @@ Spezifikation der Kolumnen. Jeder Eintrag ist ein Hash mit den
 Komponenten:
 
     {
+        name=>$name,
         titel=>$title,
+        className=>$className,
     }
 
 =item id => $id (Default: undef)
@@ -106,23 +108,20 @@ sub html {
 
     my $self = ref $this? $this: $this->new(@_);
 
-    my ($class,$columnA,$id,$rowCallback,$rowA) =
-        $self->get(qw/class columns id rowCallback rows/);
+    my ($class,$id,$rowCallback,$rowA) =
+        $self->get(qw/class id rowCallback rows/);
 
-    # Column-Hashes auf Korrektheit prüfen
-
-    for my $h (@$columnA) {
-        Prty::Hash->validate($h,[qw/title/]);
-    }
+    # Liste der Kolumnendefinitionen als Hash-Objekte
+    my @columns = $self->getColumns;
 
     # HTML generieren
 
-    if (!@$columnA) {
+    if (!@columns) {
         return '';
     }
 
     my @titles;
-    for my $col (@$columnA) {
+    for my $col (@columns) {
         push @titles,$col->{'title'};
     }
 
@@ -137,6 +136,7 @@ sub html {
             empty=>undef,
             id=>$id,
             rowCallback=>$rowCallback,
+            rowCallbackArguments=>[\@columns], # Kolumnendefinitionen
             rows=>$rowA,
             titles=>\@titles,
         ),
@@ -159,9 +159,54 @@ sub html {
 
 # -----------------------------------------------------------------------------
 
+=head2 Hilfsmethoden
+
+=head3 getColumns() - Liste der Kolumnendefinitionen
+
+=head4 Synopsis
+
+    @columns | $columns = $e->getColumns;
+
+=head4 Description
+
+Liefere die Liste der Kolumnendefinitionen. Die Kolumnen werden
+beim Setzen des Objektattributs columns als einfache Hashes
+angegeben. Diese Methode liefert die Kolumnen-Definitionen als
+Hash-Objekte (vom Typ Prty::Hash).
+
+=cut
+
+# -----------------------------------------------------------------------------
+
+sub getColumns {
+    my $self = shift;
+
+    my ($columnA) = $self->get(qw/columns/);
+
+    # Column-Hashes in Objekte wandeln und die Attribute
+    # auf Korrektheit prüfen
+
+    my @columns;
+    for my $h (@$columnA) {
+        push @columns,Prty::Hash->new([qw/
+            name
+            title
+            type
+            align
+            orderable
+            searchable
+            visible
+        /])->join($h);
+    }
+
+    return wantarray? @columns: \@columns;
+}
+
+# -----------------------------------------------------------------------------
+
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
