@@ -5,7 +5,7 @@ use strict;
 use warnings;
 use utf8;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
 use Prty::Unindent;
 use Prty::Hash;
@@ -174,12 +174,7 @@ Liste der Widgets, die in das Layout eingesetzt werden.
         onSuccess=>q|
             function () {
                 var d = new Date;
-                var date = d.getFullYear()+'-'
-                    +('0'+(d.getMonth()+1)).slice(-2)+'-'
-                    +('0'+d.getDate()).slice(-2)+' '
-                    +('0'+d.getHours()).slice(-2)+':'
-                    +('0'+d.getMinutes()).slice(-2)+':'
-                    +('0'+d.getSeconds()).slice(-2);
+                var date = $.formatDate(d,'YYYY-MM-DD hh:mm:ss');
                 $('input[name=formTime]').val(date);
             }
         |,
@@ -239,7 +234,7 @@ Liste der Widgets, die in das Layout eingesetzt werden.
 
 =head4 Synopsis
 
-    $javascript = $e->pluginCode;
+    $javascript = $class->pluginCode;
 
 =head4 Description
 
@@ -265,6 +260,7 @@ sub pluginCode {
         deleteButton: null,
         editCheckbox: null,
         widgets: null,
+        userWidgets: null,
         _create: function () {
             this.element.addClass('viewEditForm');
 
@@ -273,6 +269,23 @@ sub pluginCode {
                     this.__render();
                 },
                 'click .saveButton': function (event) {
+                    var dataFound = 0;
+
+                    this.userWidgets.each(function () {
+                        var $this = $(this);
+                        if ($this.is(':radio,:checkbox')) {
+                            if ($this.prop('checked'))
+                                dataFound++;
+                        }
+                        else {
+                            if ($this.val() != '')
+                                dataFound++;
+                        }
+                    });
+                    if (!dataFound) {
+                        alert('Bitte füllen Sie das Formular aus');
+                        return;
+                    }
                     this.__save('save');
                 },
                 'click .deleteButton': function (event) {
@@ -556,7 +569,7 @@ sub instantiate {
 
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
