@@ -3,9 +3,10 @@ package Prty::JavaScript;
 use strict;
 use warnings;
 
-our $VERSION = 1.090;
+our $VERSION = 1.091;
 
 use Prty::Path;
+use Scalar::Util ();
 
 # -----------------------------------------------------------------------------
 
@@ -120,14 +121,17 @@ sub script {
     while (@_) {
         my $spec = shift;
 
-        if (ref $spec) {
+        if (!defined $spec || $spec eq '') {
+            next;
+        }
+
+        my $type = Scalar::Util::reftype($spec);
+        if ($type && $type eq 'ARRAY') {
             unshift @_,@$spec;
             next;
         }
-        elsif (!defined $spec || $spec eq '') {
-            next;
-        }
-        elsif ($spec =~ s/^inline://) {
+
+        if ($spec =~ s/^inline://) {
             my $data = Prty::Path->read($spec);
 
             # "// eof" und Leerzeichen am Ende entfernen
@@ -161,7 +165,7 @@ sub script {
 
 =head1 VERSION
 
-1.090
+1.091
 
 =head1 AUTHOR
 
